@@ -24,36 +24,41 @@ class AuthError(Exception):
 
 
 def get_token_auth_header():
-    """Obtains the access token from the Authorization Header
+    """
+    Obtains the access token from the Authorization Header
     """
     auth = request.headers.get("Authorization", None)
     if not auth:
-        raise AuthError({"code": "authorization_header_missing",
-                         "description":
-                             "Authorization header is expected"}, 401)
+        raise AuthError({
+            "code": "authorization_header_missing",
+            "description": "Authorization header is expected",
+        }, 401)
 
     parts = auth.split()
 
     if parts[0].lower() != "bearer":
-        raise AuthError({"code": "invalid_header",
-                         "description":
-                             "Authorization header must start with"
-                             " Bearer"}, 401)
+        raise AuthError({
+            "code": "invalid_header",
+            "description": "Authorization header must start with Bearer",
+        }, 401)
     elif len(parts) == 1:
-        raise AuthError({"code": "invalid_header",
-                         "description": "Token not found"}, 401)
+        raise AuthError({
+            "code": "invalid_header",
+            "description": "Token not found",
+        }, 401)
     elif len(parts) > 2:
-        raise AuthError({"code": "invalid_header",
-                         "description":
-                             "Authorization header must be"
-                             " Bearer token"}, 401)
+        raise AuthError({
+            "code": "invalid_header",
+            "description": "Authorization header must be Bearer token",
+        }, 401)
 
     token = parts[1]
     return token
 
 
 def requires_scope(required_scope):
-    """Determines if the required scope is present in the access token
+    """
+    Determines if the required scope is present in the access token
     Args:
         required_scope (str): The scope required to access the resource
     """
@@ -68,7 +73,8 @@ def requires_scope(required_scope):
 
 
 def requires_auth(f):
-    """Determines if the access token is valid
+    """
+    Determines if the access token is valid
     """
     @wraps(f)
     def decorated(*args, **kwargs):
@@ -78,15 +84,15 @@ def requires_auth(f):
         try:
             unverified_header = jwt.get_unverified_header(token)
         except jwt.JWTError:
-            raise AuthError({"code": "invalid_header",
-                             "description":
-                                 "Invalid header. "
-                                 "Use an RS256 signed JWT Access Token"}, 401)
+            raise AuthError({
+                "code": "invalid_header",
+                "description": "Invalid header. Use an RS256 signed JWT Access Token",
+            }, 401)
         if unverified_header["alg"] == "HS256":
-            raise AuthError({"code": "invalid_header",
-                             "description":
-                                 "Invalid header. "
-                                 "Use an RS256 signed JWT Access Token"}, 401)
+            raise AuthError({
+                "code": "invalid_header",
+                "description": "Invalid header. Use an RS256 signed JWT Access Token",
+            }, 401)
         rsa_key = {}
         for key in jwks["keys"]:
             if key["kid"] == unverified_header["kid"]:
@@ -107,23 +113,27 @@ def requires_auth(f):
                     issuer="https://"+AUTH0_DOMAIN+"/"
                 )
             except jwt.ExpiredSignatureError:
-                raise AuthError({"code": "token_expired",
-                                 "description": "token is expired"}, 401)
+                raise AuthError({
+                    "code": "token_expired",
+                    "description": "token is expired",
+                }, 401)
             except jwt.JWTClaimsError:
-                raise AuthError({"code": "invalid_claims",
-                                 "description":
-                                     "incorrect claims,"
-                                     " please check the audience and issuer"}, 401)
+                raise AuthError({
+                    "code": "invalid_claims",
+                    "description": "incorrect claims, please check the audience and issuer",
+                }, 401)
             except Exception:
-                raise AuthError({"code": "invalid_header",
-                                 "description":
-                                     "Unable to parse authentication"
-                                     " token."}, 401)
+                raise AuthError({
+                    "code": "invalid_header",
+                    "description": "Unable to parse authentication token.",
+                }, 401)
 
             _request_ctx_stack.top.current_user = payload
             return f(*args, **kwargs)
-        raise AuthError({"code": "invalid_header",
-                         "description": "Unable to find appropriate key"}, 401)
+        raise AuthError({
+            "code": "invalid_header",
+            "description": "Unable to find appropriate key",
+        }, 401)
     return decorated
 
 
@@ -218,4 +228,4 @@ def check_ownership(endpoint, owner_field):
 
     return real_decorator
     
-'''
\ No newline at end of file
+'''
